Documentation
¶
Overview ¶
Package env detects what sort of environment Perkeep is running in.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DebugUploads ¶
func DebugUploads() bool
DebugUploads reports whether this is a debug environment for uploads.
func InContainer ¶
func InContainer() bool
InContainer reports whether it seems like we're running in a container.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.